@@ -7,7 +7,7 @@
 #'
 #' @param xMark x coords
 #' @param yMark y coords
-#' @param listOfdfChromSize radius
+#' @param listChrSizeText radius
 #' @param listOfdfMarkPos color
 #' @param specialChrSpacing vertices number
 #' @param chrSpacing aspect
@@ -19,13 +19,17 @@
 #' @importFrom graphics polygon text
 #'
 
-textLabel<-function(xMark,yMark,listOfdfChromSize,listOfdfMarkPos,specialChrSpacing,
+textLabel<-function(xMark,yMark,listChrSizeText1,listOfdfMarkPos,specialChrSpacing,
                     chrSpacing,markLabelSize,pattern,bannedMarkName,
                     isCentromeric=FALSE,markNewLine2,mylheight2,xsize=0) {
+
   component<-ifelse(isCentromeric,3,2)
+
   for (s in 1:length(xMark) ) {
-    corr_index<-which(names(listOfdfChromSize) %in% names(listOfdfMarkPos)[[s]] )
-    if(attr(listOfdfChromSize[[corr_index]],"ytitle")=="cM"){
+
+    corr_index<-which(names(listChrSizeText1) %in% names(listOfdfMarkPos)[[s]] )
+
+    if(attr(listChrSizeText1[[corr_index]],"ytitle")=="cM"){
       chrSpacing2<-specialChrSpacing
     } else {
       chrSpacing2<-chrSpacing
@@ -38,16 +42,13 @@ textLabel<-function(xMark,yMark,listOfdfChromSize,listOfdfMarkPos,specialChrSpac
 
           if(is.null(squareSide) ) {
             x = xMark[[s]][[m]][1] + chrSpacing2*.1
-            # y = ( yMark[[s]][[m]][1] + yMark[[s]][[m]][component] ) /2
             y = ( max(unlist(yMark[[s]][[m]])) + min(unlist(yMark[[s]][[m]])) )/2
             z=sub(pattern,"",listOfdfMarkPos[[s]]$markName[m])
             w=tryCatch(listOfdfMarkPos[[s]]$chrRegionOrig[m], error=function(e) {NA} )
             v=0
 
-
           } else if (attr(yMark[[s]][[m]],"squareSide") =="right"){
             x = xMark[[s]][[m]][1] + chrSpacing2*.1
-            # y = ( yMark[[s]][[m]][1] + yMark[[s]][[m]][component] ) /2
             y = ( max(unlist(yMark[[s]][[m]])) + min(unlist(yMark[[s]][[m]])) )/2
             z=sub(pattern,"",listOfdfMarkPos[[s]]$markName[m])
             w=tryCatch(listOfdfMarkPos[[s]]$chrRegionOrig[m], error=function(e) {NA} )
@@ -56,11 +57,18 @@ textLabel<-function(xMark,yMark,listOfdfChromSize,listOfdfMarkPos,specialChrSpac
 
           } else if (attr(yMark[[s]][[m]],"squareSide") =="left"){
             x = min(xMark[[s]][[m]]) - chrSpacing2*.1
-            # y = ( yMark[[s]][[m]][1] + yMark[[s]][[m]][component] ) /2
             y = ( max(unlist(yMark[[s]][[m]])) + min(unlist(yMark[[s]][[m]])) )/2
-            z=sub(pattern,"",listOfdfMarkPos[[s]]$markName[m])
-            w=tryCatch(listOfdfMarkPos[[s]]$chrRegionOrig[m], error=function(e) {NA} )
-            v=1
+            z = sub(pattern,"",listOfdfMarkPos[[s]]$markName[m])
+            w = tryCatch(listOfdfMarkPos[[s]]$chrRegionOrig[m], error=function(e) {NA} )
+            v= 1
+
+          } else if (attr(yMark[[s]][[m]],"squareSide") =="cMLeft") {
+
+            x=  xMark[[s]][[m]][2] - chrSpacing2*.1 # left
+            y= ( yMark[[s]][[m]][1] + yMark[[s]][[m]][component] ) /2
+            w= tryCatch(listOfdfMarkPos[[s]]$chrRegionOrig[m], error=function(e) {NA} )
+            z= sub(pattern,"",listOfdfMarkPos[[s]]$markName[m])
+            v= 1
 
           } else if (attr(yMark[[s]][[m]],"squareSide") =="exProtein"){
             x = max(unlist(xMark[[s]][[m]])) + chrSpacing2*.15
@@ -72,20 +80,21 @@ textLabel<-function(xMark,yMark,listOfdfChromSize,listOfdfMarkPos,specialChrSpac
           } else if (attr(yMark[[s]][[m]],"squareSide") =="inProtein"){
             x = max(unlist(xMark[[s]][[m]])) + xsize + chrSpacing2*.15
             y = ( max(unlist(yMark[[s]][[m]])) + min(unlist(yMark[[s]][[m]])) )/2
-            z=sub(pattern,"",listOfdfMarkPos[[s]]$markName[m])
-            w=tryCatch(listOfdfMarkPos[[s]]$chrRegionOrig[m], error=function(e) {NA} )
+            z = sub(pattern,"",listOfdfMarkPos[[s]]$markName[m])
+            w = tryCatch(listOfdfMarkPos[[s]]$chrRegionOrig[m], error=function(e) {NA} )
             v=0
           }
 
-          label=tryCatch(ifelse(any(is.na(w),is.null(w) ),z,""), error=function(e){""} )
+          label = tryCatch(ifelse(any(is.na(w),is.null(w) ),z,""), error=function(e){""} )
 
-          if(!is.na(markNewLine2) ){
-          label <- gsub(markNewLine2,"\n",label)
-          par(lheight=mylheight2) # closer together
+          if(!is.na(markNewLine2) ) {
+            label <- gsub(markNewLine2,"\n",label)
+            par(lheight=mylheight2) # closer together
           }
+
           graphics::text(x=x,
                          y=y,
-                         label= label #ifelse(is.na(w),z,"")
+                         label= label
                          ,cex=markLabelSize
                          ,adj=v
           )
@@ -95,18 +104,20 @@ textLabel<-function(xMark,yMark,listOfdfChromSize,listOfdfMarkPos,specialChrSpac
   } # for s )# l
 }
 
-textLabelCen<-function(xMark,yMark,listOfdfChromSize,listOfdfMarkPos,specialChrSpacing,chrSpacing,markLabelSize,pattern,bannedMarkName){
+textLabelCen<-function(xMark,yMark,listChrSizeText2,listOfdfMarkPos,specialChrSpacing
+                       ,chrSpacing,markLabelSize,pattern,bannedMarkName){
 
+  # s<-
   for (s in 1:length(xMark) ) {
 
-    corr_index<-which(names(listOfdfChromSize) %in% names(listOfdfMarkPos)[[s]] )
-    if(attr(listOfdfChromSize[[corr_index]],"ytitle")=="cM"){
+    corr_index<-which(names(listChrSizeText2) %in% names(listOfdfMarkPos)[[s]] )
+
+    if(attr(listChrSizeText2[[corr_index]],"ytitle")=="cM"){
       chrSpacing2<-specialChrSpacing
     } else {
       chrSpacing2<-chrSpacing
     }
 
-
     for ( m in 1:length(xMark[[s]] ) ) {
       if( !listOfdfMarkPos[[s]]$markName[m] %in% bannedMarkName ){
 
@@ -126,13 +137,15 @@ textLabelCen<-function(xMark,yMark,listOfdfChromSize,listOfdfMarkPos,specialChrS
   } # for s )# l
 }
 
-textLabelLeft<-function(xMark,yMark,listOfdfChromSize,listOfdfMarkPos,specialChrSpacing,chrSpacing,markLabelSize,pattern,
+textLabelLeft_Dep<-function(xMark,yMark,listChrSizeText3,listOfdfMarkPos,specialChrSpacing,chrSpacing,markLabelSize,pattern,
                         bannedMarkName,isCentromeric=FALSE ) {
   component<-ifelse(isCentromeric,3,2)
-  for (s in 1:length(xMark) ){
-    corr_index<-which(names(listOfdfChromSize) %in% names(listOfdfMarkPos)[[s]] )
 
-    if(attr(listOfdfChromSize[[corr_index]],"ytitle")=="cM"){
+  for (s in 1:length(xMark) ){
+
+    corr_index<-which(names(listChrSizeText3) %in% names(listOfdfMarkPos)[[s]] )
+
+    if(attr(listChrSizeText3[[corr_index]],"ytitle")=="cM"){
       chrSpacing2<-specialChrSpacing
     } else {
       chrSpacing2<-chrSpacing
@@ -147,8 +160,8 @@ textLabelLeft<-function(xMark,yMark,listOfdfChromSize,listOfdfMarkPos,specialChr
                                               adj=1 # left
         ),
         x=  xMark[[s]][[m]][2] - chrSpacing2*.1, # left
-        y=( yMark[[s]][[m]][1] + yMark[[s]][[m]][component] ) /2,
-        z=sub(pattern,"",listOfdfMarkPos[[s]]$markName[m])
+        y= ( yMark[[s]][[m]][1] + yMark[[s]][[m]][component] ) /2,
+        z= sub(pattern,"",listOfdfMarkPos[[s]]$markName[m])
       ) # m
     # )# l
     } # if
