@@ -7,12 +7,18 @@ library(gtools)
 library(knitr)
 library(rclipboard)
 library(clipr)
+library(shinyjs)
 
 devel <- FALSE
+sep <- ":"
+if(Sys.info()['sysname']=="Windows") {
+  sep <- ";"
+}
 
 if(system.file(package = "rmarkdown") != '') {
   if(rmarkdown::pandoc_available()) {
-    if(rmarkdown::pandoc_version()>2.11 & devel==F) {
+    if(rmarkdown::pandoc_version() > 2.11 & devel == F) {
+      Sys.setenv(PATH=paste0(Sys.getenv("PATH"),sep, sub(".pandoc$","",rmarkdown::pandoc_exec())))
       rmarkdown::render("www/README2.Rmd")
     }
   }
@@ -36,7 +42,7 @@ ui <- tagList(
   padding-top: 0px;
   padding-right: 0px;
   padding-bottom: 0px;
-  padding-left: 12px;
+  padding-left: 5px;
 }
 "),
   tags$div(class="container",
@@ -46,8 +52,11 @@ ui <- tagList(
                             uiOutput("mysidebar")
                           )
                           ,dashboardBody(
+                            useShinyjs(),
                             tags$head(
-                              tags$style("#markdown{height:100vh !important;}")
+                              tags$style(HTML(".fa{font-size: 12px;}") )
+                              ,tags$style(HTML(".innerI .fa {font-size: 18px;}") )
+                              ,tags$style("#markdown{height:100vh !important;}")
                               ,tags$link(rel = "stylesheet", type = "text/css", href = "mystyle.css" )
                               ,tags$style(
                                 "
